@@ -39,6 +39,20 @@ def classify_symbol(real_time_quotes_now_df):
     return real_time_quotes_now_df
 
 
+# 增加前缀
+def add_pre_prefix(real_time_quotes_now_df):
+    real_time_quotes_now_df['symbol_prefix'] = real_time_quotes_now_df['symbol'].apply(
+        lambda symbol: add_pre_prefix_one(symbol))
+    return real_time_quotes_now_df
+
+
+# 增加后缀
+def add_after_prefix(real_time_quotes_now_df):
+    real_time_quotes_now_df['symbol_prefix'] = real_time_quotes_now_df['symbol'].apply(
+        lambda symbol: add_after_prefix_one(symbol))
+    return real_time_quotes_now_df
+
+
 # 单个股票分类
 def classify_symbol_one(symbol):
     if symbol.startswith('3'):
@@ -54,6 +68,27 @@ def classify_symbol_one(symbol):
         return 'X'
 
 
+# 添加前缀
+def add_pre_prefix_one(symbol):
+    symbol_simple = symbol[0:6]
+    if symbol_simple.startswith('6'):
+        return 'SH' + symbol
+    elif symbol_simple.startswith('0') or symbol_simple.startswith('3'):
+        return 'SZ' + symbol
+    else:
+        return 'BJ' + symbol
+
+# 添加后缀
+def add_after_prefix_one(symbol):
+    symbol_simple = symbol[0:6]
+    if symbol_simple.startswith('6'):
+        return symbol + '.SH'
+    elif symbol_simple.startswith('0') or symbol_simple.startswith('3'):
+        return symbol + '.SZ'
+    else:
+        return symbol + '.BJ'
+
+
 def symbol_amount_simple(real_time_quotes_now_df):
     real_time_quotes_now_df['amount_level'] = round(real_time_quotes_now_df['amount'] / HUNDRED_MILLION, 2)
     return real_time_quotes_now_df
