@@ -19,6 +19,10 @@ def get_ths_cookie():
     return ths_cookie
 
 
+def clear_ths_cookie():
+    get_ths_cookie.cache_clear()
+
+
 @lru_cache(maxsize=None)
 def get_em_cookie():
     stock_account_info = mongodb_util.find_query_data('stock_account_info', {"type": "em_cookie", })
@@ -26,8 +30,16 @@ def get_em_cookie():
     return em_cookie
 
 
+def clear_em_cookie():
+    get_em_cookie.cache_clear()
+
+
 @lru_cache(maxsize=None)
 def get_xue_qiu_cookie():
     stock_account_info = mongodb_util.find_query_data('stock_account_info', {"type": "xue_qiu", })
     cookie = list(stock_account_info['cookie'])[0]
     return cookie
+
+
+def clear_xue_qiu_cookie():
+    get_xue_qiu_cookie.cache_clear()
